@@ -176,9 +176,9 @@ class Client(Singleton):
             ignore_prefix.append(prefix)
             return self.__put_to_cloud(path, bucket, bucket_name, tmp, tries+1, ignore_prefix=ignore_prefix)
             
-    def put_to_cloud(self, path, bucket, bucket_name, tmp=True):
+    def put_to_cloud(self, path, bucket, bucket_name, tmp=True, refresh=False):
         cache_key = 'cloud_{}_{}'.format(bucket, bucket_name)
-        cache_data = self.get_cache(cache_key, toObj=False)
+        cache_data = self.get_cache(cache_key, toObj=False) if not refresh else None
         if cache_data is None:
             ret, e = self.__put_to_cloud(path, bucket, bucket_name, tmp)
             if ret:
@@ -333,7 +333,8 @@ class Client(Singleton):
             self.redis.delkey(task_id)
         ret = self.mq.publish(self.get_topic, {
             'bucket': bucket,
-            'bucket_name': bucket_name
+            'bucket_name': bucket_name,
+            'refresh': 'yes' if refresh else 'no'
         })
         if ret:
             t = time.time()
